@@ -17,11 +17,11 @@ setClass("RangedSummarizedExperiment",
     )
 )
 
-### Combine the new "vertical slots" with those of the parent class. Make
-### sure to put the new vertical slots **first**. See R/bindROWS.R file in
-### the S4Vectors package for what slots should or should not be considered
-### "vertical".
-setMethod("vertical_slot_names", "RangedSummarizedExperiment",
+### Combine the new "parallel slots" with those of the parent class. Make
+### sure to put the new parallel slots **first**. See R/Vector-class.R file
+### in the S4Vectors package for what slots should or should not be considered
+### "parallel".
+setMethod("parallel_slot_names", "RangedSummarizedExperiment",
     function(x) c("rowRanges", callNextMethod())
 )
 
@@ -175,7 +175,7 @@ setAs("SummarizedExperiment", "RangedSummarizedExperiment",
 ### Accessors
 ###
 
-### The rowRanges() generic is defined in the DelayedArray package.
+### The rowRanges() generic is defined in the MatrixGenerics package.
 setMethod("rowRanges", "SummarizedExperiment",
     function(x, ...) NULL
 )
