@@ -7,7 +7,7 @@
 setClassUnion("Assays_OR_NULL", c("Assays", "NULL"))
 
 setClass("SummarizedExperiment",
-    contains="Vector",
+    contains=c("RectangularData", "Vector"),
     representation(
         colData="DataFrame",            # columns and their annotations
         assays="Assays_OR_NULL",        # Data -- e.g., list of matrices
@@ -16,14 +16,28 @@ setClass("SummarizedExperiment",
     )
 )
 
-### Combine the new "vertical slots" with those of the parent class. Make
-### sure to put the new vertical slots **first**. See R/bindROWS.R file in
-### the S4Vectors package for what slots should or should not be considered
-### "vertical".
-setMethod("vertical_slot_names", "SummarizedExperiment",
+### Combine the new "parallel slots" with those of the parent class. Make
+### sure to put the new parallel slots **first**. See R/Vector-class.R file
+### in the S4Vectors package for what slots should or should not be considered
+### "parallel".
+setMethod("parallel_slot_names", "SummarizedExperiment",
     function(x) c("assays", "NAMES", callNextMethod())
 )
 
+setMethod("vertical_slot_names", "SummarizedExperiment",
+    function(x) parallel_slot_names(x)
+)
+
+### Like parallel_slot_names() methods, horizontal_slot_names() methods for
+### SummarizedExperiment derivatives should be defined in an incremental
+### fashion, that is, they should only explicitly list the new "horizontal
+### slots" (i.e. the horizontal slots that they add to their parent class).
+### See R/RectangularData-class.R file in the S4Vectors package for what
+### slots should or should not be considered "horizontal".
+setMethod("horizontal_slot_names", "SummarizedExperiment",
+    function(x) "colData"
+)
+
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Validity
@@ -184,8 +198,8 @@ setMethod("assays", "SummarizedExperiment",
             function(a) {
                 a_dimnames <- dimnames(a)
                 a_dimnames[1:2] <- x_dimnames
-                dimnames(a) <- DelayedArray:::simplify_NULL_dimnames(a_dimnames)
-                a
+                a_dimnames <- DelayedArray:::simplify_NULL_dimnames(a_dimnames)
+                DelayedArray:::set_dimnames(a, a_dimnames)
             }
         )
     }
@@ -867,7 +881,7 @@ setMethod("identicalVals", c("GenomicRanges", "GenomicRanges"),
 ###
 
 setMethod("realize", "SummarizedExperiment",
-    function(x, BACKEND=getRealizationBackend())
+    function(x, BACKEND=getAutoRealizationBackend())
     {
         for (i in seq_along(assays(x))) {
             ## We drop the dimnames of the individual assays for 2 reasons:
